@@ -6,7 +6,7 @@ from sqlalchemy import Column, Float, String
 class OkexClientAccountBalance(Base, BaseTable):
     __tablename__ = 'okex_client_account_balance'
     ccy = Column(String(120), comment='币种', primary_key=True)
-    eq = Column(Float(), comment='币种总权益', primary_key=True)
+    eq = Column(Float(), comment='币种总权益')
     cashBal = Column(Float(), comment='币种余额')
     uTime = Column(Float(), comment='币种余额信息的更新时间毫秒')
 
@@ -42,7 +42,7 @@ class OkexClientAccountBalance(Base, BaseTable):
         try:
             data = res[0]['details']
             create_all()
-            
+
             for detail in data:
                 session.merge(OkexClientAccountBalance(**detail))
                 session.flush()
