@@ -13,7 +13,8 @@ from websocket import WebSocket, WebSocketException, create_connection
 
 
 class BaseConnect:
-    def __init__(self, url, channels, api_key=None, secret_key=None, passphrase=None, private=False):
+    def __init__(self, url, channels, channel_listen=None, api_key=None, secret_key=None, passphrase=None,
+                 private=False):
         self.url = url
         self.channels = channels
         self.api_key = api_key or read_secret(cate1='coin', cate2='okex', cate3='api_key')
@@ -22,6 +23,7 @@ class BaseConnect:
         self.private = private
         self.ws: WebSocket = create_connection(self.url)
         self.handles: List[BaseHandle] = []
+        self.channel_listen = channel_listen
 
     def add_handle(self, handle: BaseHandle):
         self.handles.append(handle)
@@ -29,6 +31,12 @@ class BaseConnect:
     def run(self):
         self.subscribe_start()
         while True:
+            if self.channel_listen is not None:
+                channels = self.channel_listen()
+                if channels is not None and len(channels) > 0:                
+                    if len(list(set(self.channels).intersection(set(channels)))) != len(channels):
+                        self.channels = channels
+                        self.subscribe_restart()
             try:
                 res = self.ws.recv()
             except (TimeoutError, WebSocketException):
