@@ -31,8 +31,7 @@ class OkexCoin:
         return okex
 
     def watch(self):
-        money = self.money
-        if money > 51:
+        if self.money > 51.2:
             self.sell()
 
     def __str__(self):
