@@ -1,8 +1,10 @@
 import json
 
 from notebuild.tool.fastapi import add_api_routes, api_route
+from notecoin.database.base import session
 from notecoin.database.connect import RedisConnect
-from notecoin.okex.server.const import account_account, market_tickers
+from notecoin.okex.database.client import OkexClientAccountBalance
+from notecoin.okex.server.const import market_tickers
 from notecoin.strategy.domain import OkexCoin
 
 
@@ -15,9 +17,9 @@ class AutoSeller(RedisConnect):
 
     def load_account(self):
         self.coin_map = {}
-        data = account_account.get_value()
-
-        for detail in data:
+        details = session.query(OkexClientAccountBalance).filter(OkexClientAccountBalance.eqUsd > 10).all()
+        for _detail in details:
+            detail = _detail.json()
             if detail['ccy'] == 'USDT':
                 self.usdt = float(detail['availBal'])
                 continue
@@ -43,4 +45,9 @@ class AutoSeller(RedisConnect):
         self.update_price()
         for coin in self.coin_map.values():
             coin.watch()
+            print(coin.coin_id)
         return self.to_json()
+
+
+# auto = AutoSeller()
+# auto.update_value()
